==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/fc/fcf8ed845928ecf0e5d725bb4614769b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/facebook.png */
class __TwigTemplate_561db797ca76180e91723c77218054bf extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000h\000\000\000sRGB\000\000\000\000gAMA\000\000a\000\000\000PLTEUjVlYnYn]pGhJgIgLgLgNhNiOlJhJhMiLiOlKgIhLiQjPjRlTjUkUlUmPjQlQmTmTmXnXnYoPmVpWpVpVpZpYp\\p\\r_t^tZqXr[t]r]t]uUp[u[t]v_x^ybr`rbuetdvfxm{`rau`udwdv`vbxfyeybxdyezf|f|h{k}i|m|l~i|aya{d{f}e~`|efh~wnknmgjimmonlqqwsxyz~prqtqsvvwrrtuvyxzz}xzy|{~~knqvx}{{~}|ҁąŀɅąɇˆΊŉɉȈ͌ɇёǍˊՊڒĔĖŐɐ̒ʒ̕ɕΘƜŘ̘ʓёؐݕіݛ؝ݜ㛴髼\000\000\000\000\000\000(i\000\000\000\tpHYs\000\000\000\000od\000\000IDATx^[
E&&eIOngv\\0-a\\0AOR@AH\t?  r`Ӑ F@E,@JM73e}wٛy={_#c\t4&8hLp?s^:Zv-2f'OR%Y'LK'U4iҔ߸_+ᶻq:l
pۆ.2Sy+{~_g,9qA},ӂqY:%c9vQȢ's<?9xGNAsVz%!؎uploƢ~\\\$p{/`3G|ٗf]пA
o4
g̳~lZ{_Ƿ{xu\$
Rs\\p.0Q^k!H}λ9iui9V6`H-;.X4]Or;:It6wJL`pb)/8/9dԀ}ٺܓJQūoF3rEL2y!
BYʶ9wOBcO/jce^jmE53c5S!YtlԀ `uYxGF/]q})jZcFhaǕ\tb!yBB
\\)\$eJ4ͫQ\000w5\\؅.eb<#MD2ezxnqxq6U`:(#ϽS0I:!2ހiM¦j\tW8S=
6ߴ6En~
y!wZiMSpR
r#8Ĩ!6z0wh\\sF8JH;^62qwވǡOs >6xoE -j\"gij=O\":%( ےME!<Wծ1;Er8Pw\000&J>a@H&gg)0Ŋ8po<aZƇ-%NTFã
wF_'Q(
'3MC


^kX9nVxۍ\$z^\t_)iiĹu/K6tqʁ^#jxC\\'3Z(-d<Do<#:_:2Ұ@a@ʯC:7(i7m7pYo0(Wp*]\$Lب<P-8K0M.1{'V_q+,rfV#-deh\000k\t>\t,̒~?U-.\"Ɖj\"׿c4/GYeoctq^(#؍Z]5*T\",9OMFmgFf&i6&g4]Ϝ7iTZEodAƀ#0Qp
6R#A+־hbF0}(eZi4V,5F\0003?j8DU0IǓn)\$O\$Y9e;4j8=6}6(sP\tp繏X\\qOgjÅ8\\KiF*9݌>xㄯMUsuTYuhxyܿDjNtzJsvAUQpǂ`
I4[J Q(LS<z1f/TN>q{S
(\000
yi\000[X>n:v
<*؍\"g'vMN4cMl8lxݿ\"2nYк)-04Ϙxlj}f3\"'H2FPQ۫@G
 \$ibbrsϻ:\t#Qq\tOb9|-`S,{P!KhX(ʨ3](5a/UCU8]q0(Aw=1¤UNaGc脟/̡CBǌ4*b<5-҂#'gjrs4R)L~Ds:m6,# Sp7ƅHByWPm6lNz8+k0[K6F\$&RǇNG
~ns-xxqUNոK
ۤh9tx<#38\tx'A{νUv4)\$tHŴާ\\8-nps,5Vm!FXHc\\e,g^wk~MP͡PNY
P`Ϳd\$a[,vx@IeSr9Twi9<R
!-ur?*r~C~ͧ'?!\$6O>k8vM,ƀ-'sҍ͋{ym\\^Wzg:\$ctj\000=[mp=ϹKSю^Jk\$Fj77܇wqcZp5k֬]qatR9EDU-~izT(q\tWeǆRܑF|]NPSZWٱ:ɑPb.pݎ^yTcDbՙq呰nMG~ʞW^P6E6ZJ<`xRm|y.8hk&Q=a7sx˿ڻѹ q-Q8q78,jCTW4gW!guF\$?3_#nufW8d룋9'+=[S>YGsmC`drj.]q\\92Z5zA{_#^ԇZx51o^LGSt.~P,5zЁߒ1a)1quiRrzL-.Eq.@xV\\Lr {Dze
v#cKEr9)NuҜz'J\$-iL2Wc>Q,S_&T1xJB4hnx.mbW!򶾔N0SIyHud
[&buΛ+X8?%K3IxwX8\$%xRO|EI|4qn+IϚBVg͓h\t`p/9AɎSBHL־`Mݻ˗x]vZmL]/ F`G⍥HF:W

^=?]b~AO3>^e:G#{]<h0}_JWrgT8 p;SpWT\$\000=Z#zO t\000o *V/7_MDc3q
Z=@)DuvQ<ys30Ld7᰼Ϲ\\i8_}:l۪SR
l8+0VjhEo&Oq\"ᡕe{Cp'FÕ0Ig붖|Un{QۚCZApơSF-nܴ«L鑞
Q}`ۡwMq\000>Ms.Y
LpИ1Ac\t4&8?FYY\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/facebook.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/facebook.png", "/var/www/mautic-ktn/themes/paprika/assets/facebook.png");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/fc/fcf8ed845928ecf0e5d725bb4614769b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/facebook.png */
class __TwigTemplate_561db797ca76180e91723c77218054bf extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000h\000\000\000sRGB\000\000\000\000gAMA\000\000a\000\000\000PLTEUjVlYnYn]pGhJgIgLgLgNhNiOlJhJhMiLiOlKgIhLiQjPjRlTjUkUlUmPjQlQmTmTmXnXnYoPmVpWpVpVpZpYp\\p\\r_t^tZqXr[t]r]t]uUp[u[t]v_x^ybr`rbuetdvfxm{`rau`udwdv`vbxfyeybxdyezf|f|h{k}i|m|l~i|aya{d{f}e~`|efh~wnknmgjimmonlqqwsxyz~prqtqsvvwrrtuvyxzz}xzy|{~~knqvx}{{~}|ҁąŀɅąɇˆΊŉɉȈ͌ɇёǍˊՊڒĔĖŐɐ̒ʒ̕ɕΘƜŘ̘ʓёؐݕіݛ؝ݜ㛴髼\000\000\000\000\000\000(i\000\000\000\tpHYs\000\000\000\000od\000\000IDATx^[
E&&eIOngv\\0-a\\0AOR@AH\t?  r`Ӑ F@E,@JM73e}wٛy={_#c\t4&8hLp?s^:Zv-2f'OR%Y'LK'U4iҔ߸_+ᶻq:l
pۆ.2Sy+{~_g,9qA},ӂqY:%c9vQȢ's<?9xGNAsVz%!؎uploƢ~\\\$p{/`3G|ٗf]пA
o4
g̳~lZ{_Ƿ{xu\$
Rs\\p.0Q^k!H}λ9iui9V6`H-;.X4]Or;:It6wJL`pb)/8/9dԀ}ٺܓJQūoF3rEL2y!
BYʶ9wOBcO/jce^jmE53c5S!YtlԀ `uYxGF/]q})jZcFhaǕ\tb!yBB
\\)\$eJ4ͫQ\000w5\\؅.eb<#MD2ezxnqxq6U`:(#ϽS0I:!2ހiM¦j\tW8S=
6ߴ6En~
y!wZiMSpR
r#8Ĩ!6z0wh\\sF8JH;^62qwވǡOs >6xoE -j\"gij=O\":%( ےME!<Wծ1;Er8Pw\000&J>a@H&gg)0Ŋ8po<aZƇ-%NTFã
wF_'Q(
'3MC


^kX9nVxۍ\$z^\t_)iiĹu/K6tqʁ^#jxC\\'3Z(-d<Do<#:_:2Ұ@a@ʯC:7(i7m7pYo0(Wp*]\$Lب<P-8K0M.1{'V_q+,rfV#-deh\000k\t>\t,̒~?U-.\"Ɖj\"׿c4/GYeoctq^(#؍Z]5*T\",9OMFmgFf&i6&g4]Ϝ7iTZEodAƀ#0Qp
6R#A+־hbF0}(eZi4V,5F\0003?j8DU0IǓn)\$O\$Y9e;4j8=6}6(sP\tp繏X\\qOgjÅ8\\KiF*9݌>xㄯMUsuTYuhxyܿDjNtzJsvAUQpǂ`
I4[J Q(LS<z1f/TN>q{S
(\000
yi\000[X>n:v
<*؍\"g'vMN4cMl8lxݿ\"2nYк)-04Ϙxlj}f3\"'H2FPQ۫@G
 \$ibbrsϻ:\t#Qq\tOb9|-`S,{P!KhX(ʨ3](5a/UCU8]q0(Aw=1¤UNaGc脟/̡CBǌ4*b<5-҂#'gjrs4R)L~Ds:m6,# Sp7ƅHByWPm6lNz8+k0[K6F\$&RǇNG
~ns-xxqUNոK
ۤh9tx<#38\tx'A{νUv4)\$tHŴާ\\8-nps,5Vm!FXHc\\e,g^wk~MP͡PNY
P`Ϳd\$a[,vx@IeSr9Twi9<R
!-ur?*r~C~ͧ'?!\$6O>k8vM,ƀ-'sҍ͋{ym\\^Wzg:\$ctj\000=[mp=ϹKSю^Jk\$Fj77܇wqcZp5k֬]qatR9EDU-~izT(q\tWeǆRܑF|]NPSZWٱ:ɑPb.pݎ^yTcDbՙq呰nMG~ʞW^P6E6ZJ<`xRm|y.8hk&Q=a7sx˿ڻѹ q-Q8q78,jCTW4gW!guF\$?3_#nufW8d룋9'+=[S>YGsmC`drj.]q\\92Z5zA{_#^ԇZx51o^LGSt.~P,5zЁߒ1a)1quiRrzL-.Eq.@xV\\Lr {Dze
v#cKEr9)NuҜz'J\$-iL2Wc>Q,S_&T1xJB4hnx.mbW!򶾔N0SIyHud
[&buΛ+X8?%K3IxwX8\$%xRO|EI|4qn+IϚBVg͓h\t`p/9AɎSBHL־`Mݻ˗x]vZmL]/ F`G⍥HF:W

^=?]b~AO3>^e:G#{]<h0}_JWrgT8 p;SpWT\$\000=Z#zO t\000o *V/7_MDc3q
Z=@)DuvQ<ys30Ld7᰼Ϲ\\i8_}:l۪SR
l8+0VjhEo&Oq\"ᡕe{Cp'FÕ0Ig붖|Un{QۚCZApơSF-nܴ«L鑞
Q}`ۡwMq\000>Ms.Y
LpИ1Ac\t4&8?FYY\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/facebook.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/facebook.png", "/var/www/html/mauticGIT-Test/themes/paprika/assets/facebook.png");
    }
}
